<?php

namespace App\Livewire;

use Livewire\Component;

class ResponseStatus extends Component
{
    // HTTP Status Codes from Response.js
    public $responseCodes = [
        'HTTP_CONTINUE' => 100,
        'HTTP_SWITCHING_PROTOCOLS' => 101,
        'HTTP_PROCESSING' => 102,
        'HTTP_EARLY_HINTS' => 103,
        'HTTP_OK' => 200,
        'HTTP_CREATED' => 201,
        'HTTP_ACCEPTED' => 202,
        'HTTP_NON_AUTHORITATIVE_INFORMATION' => 203,
        'HTTP_NO_CONTENT' => 204,
        'HTTP_RESET_CONTENT' => 205,
        'HTTP_PARTIAL_CONTENT' => 206,
        'HTTP_MULTI_STATUS' => 207,
        'HTTP_ALREADY_REPORTED' => 208,
        'HTTP_IM_USED' => 226,
        'HTTP_MULTIPLE_CHOICES' => 300,
        'HTTP_MOVED_PERMANENTLY' => 301,
        'HTTP_FOUND' => 302,
        'HTTP_SEE_OTHER' => 303,
        'HTTP_NOT_MODIFIED' => 304,
        'HTTP_USE_PROXY' => 305,
        'HTTP_TEMPORARY_REDIRECT' => 307,
        'HTTP_PERMANENTLY_REDIRECT' => 308,
        'HTTP_BAD_REQUEST' => 400,
        'HTTP_UNAUTHORIZED' => 401,
        'HTTP_PAYMENT_REQUIRED' => 402,
        'HTTP_FORBIDDEN' => 403,
        'HTTP_NOT_FOUND' => 404,
        'HTTP_METHOD_NOT_ALLOWED' => 405,
        'HTTP_NOT_ACCEPTABLE' => 406,
        'HTTP_PROXY_AUTHENTICATION_REQUIRED' => 407,
        'HTTP_REQUEST_TIMEOUT' => 408,
        'HTTP_CONFLICT' => 409,
        'HTTP_GONE' => 410,
        'HTTP_LENGTH_REQUIRED' => 411,
        'HTTP_PRECONDITION_FAILED' => 412,
        'HTTP_REQUEST_ENTITY_TOO_LARGE' => 413,
        'HTTP_REQUEST_URI_TOO_LONG' => 414,
        'HTTP_UNSUPPORTED_MEDIA_TYPE' => 415,
        'HTTP_REQUESTED_RANGE_NOT_SATISFIABLE' => 416,
        'HTTP_EXPECTATION_FAILED' => 417,
        'HTTP_I_AM_A_TEAPOT' => 418,
        'HTTP_MISDIRECTED_REQUEST' => 421,
        'HTTP_UNPROCESSABLE_ENTITY' => 422,
        'HTTP_LOCKED' => 423,
        'HTTP_FAILED_DEPENDENCY' => 424,
        'HTTP_UPGRADE_REQUIRED' => 426,
        'HTTP_PRECONDITION_REQUIRED' => 428,
        'HTTP_TOO_MANY_REQUESTS' => 429,
        'HTTP_REQUEST_HEADER_FIELDS_TOO_LARGE' => 431,
        'HTTP_UNAVAILABLE_FOR_LEGAL_REASONS' => 451,
        'HTTP_INTERNAL_SERVER_ERROR' => 500,
        'HTTP_NOT_IMPLEMENTED' => 501,
        'HTTP_BAD_GATEWAY' => 502,
        'HTTP_SERVICE_UNAVAILABLE' => 503,
        'HTTP_GATEWAY_TIMEOUT' => 504,
        'HTTP_VERSION_NOT_SUPPORTED' => 505,
        'HTTP_VARIANT_ALSO_NEGOTIATES_EXPERIMENTAL' => 506,
        'HTTP_INSUFFICIENT_STORAGE' => 507,
        'HTTP_LOOP_DETECTED' => 508,
        'HTTP_NOT_EXTENDED' => 510,
        'HTTP_NETWORK_AUTHENTICATION_REQUIRED' => 511,
    ];

    // Action Types from Types.js (simulated as static labels)
    public $actionTypes = [
        'LOGOUT' => 'Logout Initiated',
        'LOGOUT_SUCCESS' => 'Logout Successful',
        'LOGOUT_RESET' => 'Logout Reset',
        'FETCH_DATA' => 'Fetch Data Initiated',
        'FETCH_DATA_SUCCESS' => 'Fetch Data Successful',
        'FETCH_DATA_ERROR' => 'Fetch Data Failed',
        'FETCH_DATA_RESET' => 'Fetch Data Reset',
    ];

    public $statusCode = 200; // Default status for demo
    public $actionType = 'FETCH_DATA_SUCCESS'; // Default action type for demo

    public function mount($statusCode = 200, $actionType = 'FETCH_DATA_SUCCESS')
    {
        $this->statusCode = $statusCode;
        $this->actionType = $actionType;
    }

    public function render()
    {
        return view('livewire.response-display');
    }
}