<div class="container">
    <div class="card border" style="border-color: #E6ECF5;">
        <div class="card-header">
            <h2 class="mb-0">System Parameters</h2>
        </div>
        <div class="card-body">
            @if(!$mounted)
                <div class="text-center">
                    <div class="spinner-border text-primary" role="status">
                        <span class="visually-hidden">Loading...</span>
                    </div>
                </div>
            @else
                @if(session('success'))
                    <div class="alert alert-success mb-3" role="alert">
                        {{ session('success') }}
                    </div>
                @endif
                @if(session('error'))
                    <div class="alert alert-danger mb-3" role="alert">
                        {{ session('error') }}
                    </div>
                @endif

                <form wire:submit.prevent="update">
                    <h3 class="mb-4">Company Logo</h3>
                    <div class="row mb-3">
                        <label for="logo" class="col-sm-2 col-form-label">Upload Image</label>
                        <div class="col-sm-6">
                            <input type="file" class="form-control @error('logo') is-invalid @enderror" wire:model="logo" id="logo" accept=".jpg,.png">
                            @error('logo') <div class="invalid-feedback">{{ $message }}</div> @enderror
                            @if($logo)
                                <img src="{{ $logo->temporaryUrl() }}" alt="Logo Preview" style="max-width: 294px; margin-top: 10px;">
                            @elseif($systemPreference['logo'])
                                <img src="{{ $systemPreference['logo'] }}" alt="Current Logo" style="max-width: 294px; margin-top: 10px;">
                            @endif
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">GPS Radius</h3>
                    <div class="row mb-3">
                        <label for="gps" class="col-sm-2 col-form-label">GPS Radius (in meters)</label>
                        <div class="col-sm-6">
                            <input type="number" class="form-control @error('gps') is-invalid @enderror" wire:model="gps" id="gps" placeholder="0" min="0">
                            @error('gps') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">Customer Service Details</h3>
                    <div class="row mb-3">
                        <label for="contact_email_address_mobile" class="col-sm-2 col-form-label">Contact Email Address</label>
                        <div class="col-sm-6">
                            <input type="email" class="form-control @error('contact_email_address_mobile') is-invalid @enderror" wire:model="contact_email_address_mobile" id="contact_email_address_mobile" placeholder="username@domain.com">
                            @error('contact_email_address_mobile') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="contact_number_mobile" class="col-sm-2 col-form-label">Contact Number</label>
                        <div class="col-sm-6">
                            <input type="text" class="form-control @error('contact_number_mobile') is-invalid @enderror" wire:model="contact_number_mobile" id="contact_number_mobile" placeholder="63 947 687 9999">
                            @error('contact_number_mobile') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">System Administrator Details</h3>
                    <div class="row mb-3">
                        <label for="contact_details" class="col-sm-2 col-form-label">Contact Details</label>
                        <div class="col-sm-6">
                            <input type="email" class="form-control @error('contact_details') is-invalid @enderror" wire:model="contact_details" id="contact_details" placeholder="Contact Email">
                            @error('contact_details') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">Information Guide Details</h3>
                    <div class="row mb-3">
                        <label for="information_guide_details" class="col-sm-2 col-form-label">Details</label>
                        <div class="col-sm-6">
                            <textarea class="form-control @error('information_guide_details') is-invalid @enderror" wire:model="information_guide_details" id="information_guide_details" rows="4" maxlength="100" placeholder="Details"></textarea>
                            <small class="form-text text-muted">{{ strlen($information_guide_details) }}/100 characters</small>
                            @error('information_guide_details') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">Android Version Update</h3>
                    <div class="row mb-3">
                        <label for="android_version" class="col-sm-2 col-form-label">Android Version</label>
                        <div class="col-sm-6">
                            <input type="text" class="form-control @error('android_version') is-invalid @enderror" wire:model="android_version" id="android_version" maxlength="20" placeholder="Android Version">
                            <small class="form-text text-muted">{{ strlen($android_version) }}/20 characters</small>
                            @error('android_version') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="android_update_message" class="col-sm-2 col-form-label">Version Update Message</label>
                        <div class="col-sm-6">
                            <textarea class="form-control @error('android_update_message') is-invalid @enderror" wire:model="android_update_message" id="android_update_message" rows="4" maxlength="100" placeholder="Android Version"></textarea>
                            <small class="form-text text-muted">{{ strlen($android_update_message) }}/100 characters</small>
                            @error('android_update_message') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="android_action" class="col-sm-2 col-form-label">Version Action</label>
                        <div class="col-sm-6">
                            <select class="form-select @error('android_action') is-invalid @enderror" wire:model="android_action" id="android_action">
                                <option value="">Select Version Action</option>
                                @foreach($actionAndroidTypeOptions as $option)
                                    <option value="{{ $option['value'] }}">{{ $option['label'] }}</option>
                                @endforeach
                            </select>
                            @error('android_action') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">IOS Version Update</h3>
                    <div class="row mb-3">
                        <label for="ios_version" class="col-sm-2 col-form-label">IOS Version</label>
                        <div class="col-sm-6">
                            <input type="text" class="form-control @error('ios_version') is-invalid @enderror" wire:model="ios_version" id="ios_version" maxlength="20" placeholder="IOS Version">
                            <small class="form-text text-muted">{{ strlen($ios_version) }}/20 characters</small>
                            @error('ios_version') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="ios_update_message" class="col-sm-2 col-form-label">Version Update Message</label>
                        <div class="col-sm-6">
                            <textarea class="form-control @error('ios_update_message') is-invalid @enderror" wire:model="ios_update_message" id="ios_update_message" rows="4" maxlength="100" placeholder="IOS Version"></textarea>
                            <small class="form-text text-muted">{{ strlen($ios_update_message) }}/100 characters</small>
                            @error('ios_update_message') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="ios_action" class="col-sm-2 col-form-label">Version Action</label>
                        <div class="col-sm-6">
                            <select class="form-select @error('ios_action') is-invalid @enderror" wire:model="ios_action" id="ios_action">
                                <option value="">Select Version Action</option>
                                @foreach($actionIosTypeOptions as $option)
                                    <option value="{{ $option['value'] }}">{{ $option['label'] }}</option>
                                @endforeach
                            </select>
                            @error('ios_action') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>
                    <hr class="my-5" style="border-color: #e6ecf5;">

                    <h3 class="mb-4">Update Details</h3>
                    <div class="row mb-3">
                        <div class="col-sm-6 offset-sm-2">
                            <button type="button" wire:click="syncStratuscast" class="btn btn-primary" wire:loading.attr="disabled" wire:target="syncStratuscast" data-bs-toggle="tooltip" data-bs-placement="top" title="Select this button to sync City and Province, Products, and Stations from the Unioil Website to the Unioil Mobile App system.">
                                <span wire:loading wire:target="syncStratuscast">Syncing Data Please wait...</span>
                                <span wire:loading.remove wire:target="syncStratuscast">Sync Data</span>
                            </button>
                        </div>
                    </div>

                    <div class="text-center mt-4">
                        <button type="submit" class="btn btn-primary" wire:loading.attr="disabled" wire:target="update">
                            <span wire:loading wire:target="update">Submitting...</span>
                            <span wire:loading.remove wire:target="update">Submit</span>
                        </button>
                    </div>
                </form>
            @endif
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<script>
    // Initialize Bootstrap tooltips
    document.addEventListener('DOMContentLoaded', function () {
        var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
        var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
            return new bootstrap.Tooltip(tooltipTriggerEl);
        });
    });
</script>

@if(session('success'))
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        Swal.fire({
            icon: 'success',
            title: 'Success',
            text: '{{ session('success') }}',
        });
    </script>
@endif

@if(session('error'))
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: '{{ session('error') }}',
        });
    </script>
@endif